% For use with Matlab
% Copyright (C) 2019 -- Jérôme Mendes <jermendes@gmail.com> or <jermendes@isr.uc.pt>, Rui Araújo <rui@isr.uc.pt>
% Jérôme Mendes, Francisco Souza, and Rui Araújo. "Online Evolving Fuzzy Control Design: An Application to a CSTR Plant". In Proc. IEEE 15th International Conference on Industrial Informatics (INDIN 2017), 2017.
% The "SEDFLC toolbox" comes with ABSOLUTELY NO WARRANTY;
% In case of publication of any application of this method, please, cite the work:
% Jérôme Mendes, Francisco Souza and Rui Araújo. 
% Online Evolving Fuzzy Control Design: An Application to a CSTR Plant.
% In Proc. IEEE 15th International Conference on Industrial Informatics (INDIN 2017), pages 1-8, Emden, Germany, July 24 - July 17
% DOI: https://doi.org/10.1109/INDIN.2017.8104774
% http://www.isr.uc.pt/~jermendes/    ;     http://www.isr.uc.pt/~rui/

function [data_window] = update_window( data_window, yk, uk, data_inputs, window_size)
%% Description
% This function updates the temporal sliding window

%% Function inputs
% data_window - temporal sliding window
% yk - output variable of the plant to be controlled
% uk - command signal
% data_input -  values of the input variable 
% window_size - Size of the temporal sliding window 

%% Function output
% data_window - temporal sliding window

actual_size_window = size(data_window, 2); % size of the temporal sliding window 

new_data = [yk; data_inputs(2:end)'; data_inputs(1); uk]; % data to be stored on the temporal sliding window - [ yk+1; variables without ref; ref; uk]

%% Update the temporal sliding window
if actual_size_window < window_size % if the temporal sliding window is not filled yet
    data_window = [data_window new_data];
else% if the temporal sliding window is filled 
    data_window = [data_window(:,2:end) new_data]; 
end

end